@@ -16,3 +16,9 @@ class SchemaParsingError(BaseException):
 
 class SchemaFieldError(BaseException):
     pass
+
+class UnknownTransmutator(BaseException):
+    pass
+
+class TransmutatorError(BaseException):
+    pass
\ No newline at end of file
